AGN_DATA = {};
--- @type table<number, FieldInfo>
AGN_DATA.fields = {
    {
        id = "HonorLevel",
        guildInfoId = "H",
        description = "The player's current honor level",
        get = function()
            --- @type integer
            local honorLevel = UnitHonorLevel("player");

            return honorLevel;
        end,
        getString = function(self) return "HL" .. self.get(); end,
    }, {
        id = "ItemLevel",
        guildInfoId = "I",
        description = "The player's equipped item level",
        get = function()
            --- @type integer
            local itemLevel = C_PaperDollInfo.GetInspectItemLevel("player");

            return itemLevel;
        end,
        getString = function(self) return "i" .. self.get() end,
    }, {
        id = "PvPBracket",
        guildInfoId = "P",
        description = "The player's current best pvp rating and the respective bracket",
        get = function()
            local bracket = nil;
            local rating = 0;

            local rating2v2 = GetInspectArenaData(1);
            if (rating2v2 > rating) then
                bracket = "2v2";
                rating = rating2v2;
            end

            local rating3v3 = GetInspectArenaData(2);
            if (rating3v3 > rating) then
                bracket = "3v3";
                rating = rating3v3;
            end

            local ratingRbg = GetInspectArenaData(4);
            if (ratingRbg > rating) then
                bracket = "rbg";
                rating = ratingRbg;
            end

            return rating, bracket
        end,
        getString = function(self)
            local rating, bracket = self.get();
            if bracket == nil then return nil; end

            return "CR" .. rating .. "(" .. bracket .. ")";
        end,
    }, {
        id = "Versatility",
        guildInfoId = "V",
        description = "The player's current versatility % bonus",
        get = function() return AGN:GetVersatilityDamagePercent(); end,
        getString = function(self) return ("v%i%%"):format(self.get()); end,
    }, {
        id = "Specialization",
        guildInfoId = "S",
        description = "The player's current specialization",
        get = function()
            local specId = GetSpecialization();
            local _, specName = GetSpecializationInfo(specId);

            return specName;
        end,
        getString = function(self) return self.get(); end,
    },
};

--- @class FieldInfo
--- @field id string
--- @field guildInfoId string
--- @field description string
--- @field get function
--- @field getString function
